__version__ = "0.1.6"
__git_commiter_name__ = "Arnon Yaari"
__git_commiter_email__ = "arnony@infinidat.com"
__git_branch__ = '(detached from v0.1.6)'
__git_remote_tracking_branch__ = '(No remote tracking)'
__git_remote_url__ = '(Not remote tracking)'
__git_head_hash__ = '0671d68a312dfd0a61ab9028715efba3045bbd16'
__git_head_subject__ = 'update homepage'
__git_head_message__ = ''
__git_dirty_diff__ = ''